@@ -7,7 +7,7 @@ __author__ = "P J Kershaw"
 __date__ = "15/02/10"
 __copyright__ = "(C) 2010 Science and Technology Facilities Council"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = "$Id: queryinterface.py 7526 2010-09-27 12:08:12Z pjkersha $"
+__revision__ = "$Id: queryinterface.py 7634 2010-10-20 20:23:29Z pjkersha $"
 __license__ = "http://www.apache.org/licenses/LICENSE-2.0"
 import logging
 log = logging.getLogger(__name__)
@@ -390,7 +390,7 @@ class SOAPQueryInterfaceMiddleware(SOAPMiddleware):
         soapRequest.parse(StringIO(soapRequestTxt))
         
         log.debug("SOAPQueryInterfaceMiddleware.__call__: received SAML "
-                  "SOAP SQuery ...")
+                  "SOAP Query: %s", soapRequestTxt)
        
         queryElem = soapRequest.body.elem[0]
         
