@@ -24,7 +24,7 @@ __date__ = "21/07/09"
 __copyright__ = "(C) 2009 Science and Technology Facilities Council"
 __license__ = "http://www.apache.org/licenses/LICENSE-2.0"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = '$Id: test_saml.py 7130 2010-06-30 13:33:07Z pjkersha $'
+__revision__ = '$Id: test_saml.py 7634 2010-10-20 20:23:29Z pjkersha $'
 import logging
 logging.basicConfig(level=logging.DEBUG)
     
@@ -38,6 +38,7 @@ import pickle
 from xml.etree.ElementTree import iselement
 from xml.etree import ElementTree
 
+from ndg.saml.utils import SAMLDateTime
 from ndg.saml.saml2.core import (SAMLVersion, Attribute, AttributeStatement, 
                                  AuthzDecisionStatement, Assertion, 
                                  AttributeQuery, Response, Issuer, Subject, 
@@ -741,5 +742,16 @@ class SAMLTestCase(unittest.TestCase):
         self.assert_(response2.assertions[0].authzDecisionStatements[0
                         ].decision == DecisionType.PERMIT)        
         
+    def test17SAMLDatetime(self):
+        # Test parsing of Datetimes following 
+        # http://www.w3.org/TR/xmlschema-2/#dateTime 
+        
+        # No seconds fraction
+        self.assert_(SAMLDateTime.fromString('2010-10-20T14:49:50Z'))
+        
+        self.assertRaises(TypeError, SAMLDateTime.fromString, 
+                          None)
+        
+        
 if __name__ == "__main__":
     unittest.main()        
